@@ -15,6 +15,7 @@ pub struct GetListUsersBody {
 #[derive(Serialize, Deserialize, Debug, Clone)]
 pub struct GetListUsersResult {
     pub list: Vec<UserAggregation>,
+    pub count: i32
 }
 
 #[derive(Serialize, Deserialize, Debug, Clone)]
@@ -29,6 +30,11 @@ pub struct UserAggregation {
     pub company: Option<CompanyAggregation>,
 }
 
+#[derive(Serialize, Deserialize, Debug, Clone)]
+pub struct UserCount {
+    pub count: i32
+}
+
 #[derive(Serialize, Deserialize, Debug, Clone)]
 pub struct AccountActivationAggregation {
     pub activation_date: Option<String>,
@@ -101,6 +107,66 @@ pub struct AccountSettingsAggregation {
     pub currency: Option<String>,
 }
 
+#[derive(Serialize, Deserialize, Debug, Clone)]
+pub struct id_name {
+    pub id: Option<String>,
+    pub name: Option<String>,
+}
+
+#[derive(Serialize, Deserialize, Debug, Clone)]
+pub struct CompanyAddressDetail {
+    pub country : Option<id_name>,
+    pub city : Option<id_name>,
+}
+
+#[derive(Serialize, Deserialize, Debug, Clone)]
+pub struct CompanySettingDetail {
+    pub activities : Option<Vec<id_name>>,
+    pub address: Option<CompanyAddressDetail>,
+    pub legal_form: Option<id_name>,
+    pub social_kinds: Option<Vec<id_name>>,
+}
+
+#[derive(Serialize, Deserialize, Debug, Clone)]
+pub struct CompanySettingsAggregation {
+    pub country: Option<id_name>,
+    pub city: Option<id_name>,
+    pub kind : Option<id_name>,
+    pub gender: Option<id_name>,
+    pub civil_status: Option<id_name>,
+    pub activation_status : Option<id_name>,
+    pub company : Option<CompanySettingDetail>,
+    pub user_social_kinds: Option<Vec<id_name>>,
+}
+
+#[derive(Serialize, Deserialize, Debug, Clone)]
+pub struct AddressIn {
+    pub country: Option<String>,
+    pub city: Option<String>,
+}
+
+#[derive(Serialize, Deserialize, Debug, Clone)]
+pub struct CompanyIn {
+    pub activities: Vec<String>,
+    pub address: Option<AddressIn>,
+    pub legal_form: Option<String>,
+    pub social_kinds: Vec<String>,
+}
+
+#[derive(Serialize, Deserialize, Debug, Clone)]
+pub struct GetCompanySettingsInput {
+    pub company: Option<CompanyIn>,
+    pub user_social_kinds: Vec<String>,
+    pub activation_status: Option<String>,
+    pub country: Option<String>,
+    pub city: Option<String>,
+    pub kind: Option<String>,
+    pub gender: Option<String>,
+    pub civil_status: Option<String>,
+    pub language_code: Option<String>,
+}
+
+
 #[derive(Serialize, Deserialize, Debug, Clone)]
 pub struct CompanyAggregation {
     pub id: Option<String>,
